slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSGDSetBOrth

Selects the orthogonalization that will be used in the search subspace in case of generalized Hermitian problems.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSGDSetBOrth(EPS eps,PetscBool borth)

Logically Collective on eps

### Input Parameters

| eps | - the eigenproblem solver context
| borth | - whether to B-orthogonalize the search subspace

### Options Database Key

| -eps_gd_borth | - Set the orthogonalization used in the search subspace

### See Also

EPSGDGetBOrth()

### Level

advanced

### Location

src/eps/impls/davidson/gd/gd.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages